@@ -13,6 +13,9 @@ class ProbitLink : public LinkBase
   Eigen::ArrayXd computeMean(const Eigen::ArrayXd&) const;
   Eigen::ArrayXd computeMeanDerivative(const Eigen::ArrayXd&) const;
   Eigen::ArrayXd computeMeanSecondDerivative(const Eigen::ArrayXd&) const;
+  Eigen::ArrayXd computeMeanThirdDerivative(const Eigen::ArrayXd&) const;
+  Eigen::ArrayXd computeMeanFourthDerivative(const Eigen::ArrayXd&) const;
+
   std::string getName() const;
 
  private:
